#!/bin/sh
#
# Copyright (C) 2011 by Christian Ptzsch
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

# configuration

# the base of the usb stick goes here:
BASE=""
# add the encrypted root password here:
PASS=""
# add the ip of the FRITZ!Box
ROUTER=""

# common function follow 

# enable for debugging
#set -x

# some apps
ECHO=/bin/echo
LS=/bin/ls
MKDIR=/bin/mkdir
MOUNT=/bin/mount
LN=/bin/ln
GREP=/bin/grep
CP=/bin/cp
CHMOD=/bin/chmod

# check for an error and exists
# $1: the error
# $2: the error message
_lce()
{
  if [ ${1} -ne 0 ]; then
    "${ECHO}" "Error: ${2}"
    exit ${1}
  fi
} 

# checks if a path is mounted
# $1: the path
_lchkmnt()
{
  "${MOUNT}" | "${GREP}" -q "${1}"
}

# mount a device
# $1: device
# $2: the target directory
# $3: options
_lmnt()
{
  "${MOUNT}" ${3} "${1}" "${2}" || _lce $? "Can't mount ${1} to ${2}"
}

# creates a directory if it not exists already 
# $1: the directory to create
_lmkdir()
{
  if [ ! -e "${1}" -a ! -h "${1}" ]; then
    "${MKDIR}" -p "${1}" || _lce $? "Can't mkdir ${1}"
  fi
}

# copy a file if it not already exists 
# $1: the source of the link
# $2: the target of the link
_lcp_file()
{
  if [ ! -e "${2}" -a ! -h "${2}"  ]; then
    "${CP}" -d "${1}" "${2}" || _lce $? "Can't copy file ${1} to ${2}"
  fi 
}

# chmod a file if it exists
_lchmod()
{
  if [ -e "${2}" ]; then
    "${CHMOD}" "${1}" "${2}" || _lce $? "Can't chmod file ${2}"
  fi
}

# symlink a file if it not already exists 
# $1: the source of the link
# $2: the target of the link
_lsymlnk_file()
{
  if [ ! -e "${2}" -a ! -h "${2}" ]; then
   "${LN}" -s "${1}" "${2}" || _lce $? "Can't link ${2} to ${1}"
  fi
}

# recursivly symlink a directory
# $1: the base of the source directory 
# $2: the subdirectory within base which should be symlinked
# $3: the target directory to link to
_lsymlnk_dir()
{
  local SRCBASE="${1}"
  local SRC="${2}"
  local TRGBASE="${3}"
  local SRCPATH="${SRCBASE}/${SRC}"
  local TRGPATH="${TRGBASE}/${SRC}"
  local CNT="`${LS} ${SRCPATH}`"
  _lmkdir "${TRGPATH}"
  for i in ${CNT}; do
    if [ -h "${SRCPATH}/${i}" ]; then
      _lcp_file "${SRCPATH}/${i}" "${TRGPATH}/${i}"
    elif [ -d "${SRCPATH}/${i}" ]; then
      _lsymlnk_dir "${SRCPATH}" "${i}" "${TRGPATH}"
    elif [ -f "${SRCPATH}/${i}" ]; then
      _lsymlnk_file "$SRCPATH/${i}" "${TRGPATH}/${i}"
    fi
  done
}

[ "x${BASE}" = "x" ] && _lce 1 "no base directory is set in common.sh"
[ ! -e "${BASE}" ]   && _lce 1 "base directory doesn't exists"
