#!/bin/sh
#                                            
# Copyright (C) 2011 by Christian Ptzsch
#                                                                             
# Permission is hereby granted, free of charge, to any person obtaining a copy 
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#                                                                           
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#                                                                           
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,   
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER       
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

. common.sh

MNT=/var/_overlay_
BASE_RO=/var/_ro_
BASE_OVL="${BASE}/local"

DIRS="lib etc usr/bin usr/sbin usr/lib usr/share"

echo "Installing software from ${BASE} ..."

# remount root readonly
echo "Mounting root readonly ..."
"${MOUNT}" | "${GREP}" "/dev/root" | "${GREP}" -q ro
[ $? -eq 1 ] && _lmt /dev/root / "-o remount -r"
# bind root into var
_lchkmnt "${BASE_RO}" 
if [ $? -eq 1 ]; then
  echo "Mounting root to ${BASE_RO}"
  _lmkdir "${BASE_RO}"
  _lmnt / "${BASE_RO}" "-o bind"
fi

# create our overlay dir
_lchkmnt "${MNT}" 
if [ $? -eq 1 ]; then
  echo "Creating overlay directory ${MNT}"
  _lmkdir "${MNT}"
  _lmnt tmpfs "${MNT}" "-t tmpfs"
fi

# link/copy the base stuff
echo "Copying the base apps ..."
for i in ${DIRS}; do
  _lsymlnk_dir "${BASE_RO}" "${i}" "${MNT}"
done

# link/copy our own stuff
echo "Copying the overlay apps ..."
for i in ${DIRS}; do
  _lsymlnk_dir "${BASE_OVL}" "${i}" "${MNT}"
done

# now bind all overlay dirs to root 
# (this is critical don't interupt)
echo "Bind the overlay dirs ..."
for i in ${DIRS}; do
  _lmnt "${MNT}/${i}" "/${i}" "-o bind"
done

exit 0
